@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "0.12.0"
+version = "0.12.1"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -183,6 +183,11 @@ compare_inode = 1
 # guarantee that any changes have been committed to disk.
 fsync_directories = 1
 
+# If set, directory increments are given the same permissions as the
+# directories they represent.  Otherwise they have the default
+# permissions.
+change_dir_inc_perms = 1
+
 
 def get(name):
 	"""Return the value of something in this module"""
